@@ -1,16 +1,14 @@
 """Integration tests for Conoha"""
 from unittest import TestCase
 
-from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.conoha import Provider
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
-class ConohaProviderTests(TestCase, IntegrationTests):
+class ConohaProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for Conoha"""
-    Provider = Provider
     provider_name = 'conoha'
     domain = 'narusejun.com'
 
