@@ -2,13 +2,13 @@
 from unittest import TestCase
 
 import pytest
-from lexicon.tests.providers.integration_tests import IntegrationTests
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
-class DigitalOceanProviderTests(TestCase, IntegrationTests):
+class DigitalOceanProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for DigitalOcean"""
     provider_name = 'digitalocean'
     domain = 'foxwoodswebsites.com'
