@@ -1,13 +1,11 @@
 """Integration tests for EasyName"""
 from unittest import TestCase
 
-from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.easyname import Provider
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
-class EasynameProviderTests(TestCase, IntegrationTests):
+class EasynameProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for EasyName"""
-    Provider = Provider
     provider_name = 'easyname'
     domain = 'lexicontest.astzweig.de'
 
